==> hesseflux-2.0.2.tar.gz: hesseflux-2.0.2/README.md <==
# hesseflux - Eddy covariance flux data processing of FR-Hes
<!-- pandoc -f gfm -o README.html -t html README.md -->

*hesseflux* provides functions used in the processing and
post-processing of the Eddy covariance flux data of the
[ICOS](https://www.icos-cp.eu/) ecosystem site
[FR-Hes](https://www.icos-france.fr/en/static3/the-network).

[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.3831488.svg)](https://doi.org/10.5281/zenodo.3831488)
[![PyPI version](https://badge.fury.io/py/hesseflux.svg)](https://badge.fury.io/py/hesseflux)
[![License](http://img.shields.io/badge/license-MIT-blue.svg?style=flat)](https://github.com/mcuntz/hesseflux/blob/master/LICENSE)
[![Build Status](https://travis-ci.org/mcuntz/hesseflux.svg?branch=master)](https://travis-ci.org/mcuntz/hesseflux)
[![Coverage Status](https://coveralls.io/repos/github/mcuntz/hesseflux/badge.svg)](https://coveralls.io/github/mcuntz/hesseflux)
[![Documentation Status](https://readthedocs.org/projects/hesseflux/badge/?version=latest)](https://hesseflux.readthedocs.io/en/latest/?badge=latest)


## About hesseflux

*hesseflux* collects functions used for processing Eddy covariance data
of the ICOS ecosystem site FR-Hes.

The package uses several functions of the JAMS Python package
https://github.com/mcuntz/jams_python  
The JAMS package and *hesseflux* are synchronised irregularily.

*hesseflux* includes a Python port of Logtools, the Logger Tools
Software of Olaf Kolle, MPI-BGC Jena, (c) 2012.

The post-processing functionality for Eddy flux data is similar to the
R-package
[REddyProc](https://cran.r-project.org/web/packages/REddyProc/index.html)
and includes basically the steps described in
[Papale et al. (Biogeosciences, 2006)](https://doi.org/10.5194/bg-3-571-2006)
plus some extensions such as the daytime method of flux partitioning
([Lasslop et al., Global Change Biology 2010](https://doi.org/10.1111/j.1365-2486.2009.02041.x)).


## Documentation

The complete documentation for *hesseflux* is available from Read The Docs.

   http://hesseflux.readthedocs.org/en/latest/


## Quick usage guide

### Post-processing Eddy covariance data that is in europe-fluxdata.eu format

An example script that makes all the steps described in
[Papale et al. (Biogeosciences, 2006)](https://doi.org/10.5194/bg-3-571-2006)
is given in the example directory. It is simply called:

```bash
    python postproc_europe-fluxdata.py hesseflux_example.cfg
```

The script is governed by a configuration file in Python's standard
configparser format. The example configuration file
`hesseflux_example.cfg` is highly commented. See the
[User Guide](http://hesseflux.readthedocs.org/en/latest/userguide.html)
for a step by step guide through the script and the configuration
file.


## Installation

The easiest way to install is via `pip`::

    pip install hesseflux

See the
[installation instructions](http://hesseflux.readthedocs.io/en/latest/install.html)
in the [documentation](http://hesseflux.readthedocs.io) for more
information.


## Requirements:

- [NumPy](https://www.numpy.org)
- [SciPy](https://www.scipy.org/scipylib)


## License

*hesseflux* is distributed under the MIT License.  
See the [LICENSE](https://github.com/mcuntz/hesseflux/LICENSE) file for details.

Copyright (c) 2009-2020 Matthias Cuntz

The project structure is based on a
[template](https://github.com/MuellerSeb/template) provided by
[Sebastian Müller](https://github.com/MuellerSeb).

## Contributing to hesseflux

Users are welcome to submit bug reports, feature requests, and code
contributions to this project through GitHub.  
More information is available in the
[Contributing](http://hesseflux.readthedocs.org/en/latest/contributing.html)
guidelines.

==> hesseflux-3.2.tar.gz: hesseflux-3.2/README.md <==
# hesseflux - Eddy covariance flux data processing of FR-Hes
<!-- pandoc -f gfm -o README.html -t html README.md -->

*hesseflux* provides functions used in the processing and
post-processing of the Eddy covariance flux data of the
[ICOS](https://www.icos-cp.eu/) ecosystem site
[FR-Hes](https://www.icos-france.fr/en/static3/the-network).

[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.3831488.svg)](https://doi.org/10.5281/zenodo.3831488)
[![PyPI version](https://badge.fury.io/py/hesseflux.svg)](https://badge.fury.io/py/hesseflux)
[![License](http://img.shields.io/badge/license-MIT-blue.svg?style=flat)](https://github.com/mcuntz/hesseflux/blob/master/LICENSE)
[![Build Status](https://travis-ci.org/mcuntz/hesseflux.svg?branch=master)](https://travis-ci.org/mcuntz/hesseflux)
[![Coverage Status](https://coveralls.io/repos/github/mcuntz/hesseflux/badge.svg)](https://coveralls.io/github/mcuntz/hesseflux)
[![Documentation Status](https://readthedocs.org/projects/hesseflux/badge/?version=latest)](https://hesseflux.readthedocs.io/en/latest/?badge=latest)


## About hesseflux

*hesseflux* collects functions used for processing Eddy covariance data
of the ICOS ecosystem site FR-Hes.

The package uses several functions of the JAMS Python package
https://github.com/mcuntz/jams_python  
The JAMS package and *hesseflux* are synchronised irregularly.

*hesseflux* includes a Python port of Logtools, the Logger Tools
Software of Olaf Kolle, MPI-BGC Jena, (c) 2012.

The post-processing functionality for Eddy flux data is similar to the
R-package
[REddyProc](https://cran.r-project.org/web/packages/REddyProc/index.html)
and includes basically the steps described in
[Papale et al. (Biogeosciences, 2006)](https://doi.org/10.5194/bg-3-571-2006)
plus some extensions such as the daytime method of flux partitioning
([Lasslop et al., Global Change Biology 2010](https://doi.org/10.1111/j.1365-2486.2009.02041.x)).


## Documentation

The complete documentation for *hesseflux* is available from Read The Docs.

   http://hesseflux.readthedocs.org/en/latest/


## Quick usage guide

### Post-processing Eddy covariance data that is in europe-fluxdata.eu format

An example script that makes all the steps described in
[Papale et al. (Biogeosciences, 2006)](https://doi.org/10.5194/bg-3-571-2006)
is given in the example directory. It is simply called:

```bash
    python postproc_europe-fluxdata.py hesseflux_example.cfg
```

The script is governed by a configuration file in Python's standard
configparser format. The example configuration file
`hesseflux_example.cfg` is highly commented. See the
[User Guide](http://hesseflux.readthedocs.org/en/latest/userguide.html)
for a step by step guide through the script and the configuration
file.


## Installation

The easiest way to install is via `pip`::

    pip install hesseflux

See the
[installation instructions](http://hesseflux.readthedocs.io/en/latest/install.html)
in the [documentation](http://hesseflux.readthedocs.io) for more
information.


## Requirements:

- [NumPy](https://www.numpy.org)
- [SciPy](https://www.scipy.org/scipylib)


## License

*hesseflux* is distributed under the MIT License.  
See the [LICENSE](https://github.com/mcuntz/hesseflux/LICENSE) file for details.

Copyright (c) 2009-2020 Matthias Cuntz

The project structure is based on a
[template](https://github.com/MuellerSeb/template) provided by
[Sebastian Müller](https://github.com/MuellerSeb).

## Contributing to hesseflux

Users are welcome to submit bug reports, feature requests, and code
contributions to this project through GitHub.

More information is available in the
[Contributing](http://hesseflux.readthedocs.org/en/latest/contributing.html)
guidelines.
